# Sift Stream Python Bindings

[![pypi](https://img.shields.io/pypi/v/sift-stream-bindings)](https://pypi.org/project/sift-stream-bindings/)
[![pypi](https://img.shields.io/pypi/pyversions/sift-stream-bindings)](https://pypi.org/project/sift-stream-bindings/)

This library provides Python bindings for the `sift_stream` crate, offering access to the core functionality offered by `sift_stream` via Python. It is built using [pyo3](https://docs.rs/pyo3/latest/pyo3/) and published using [maturin](https://github.com/PyO3/maturin). This library is built with the intention of being used within the underlying architecture of the sift-stack-py package.
